/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *    Brutus header file for Brutus utility functions.
 *    Copyright (C) 2005-2007 OMC Denmark ApS.
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *    MA 02111-1307 USA
 */

#ifndef _BRUTUS_UTIL_H_
#define _BRUTUS_UTIL_H_

#include <glib.h>
#include <libecal/e-cal.h>

#include <idl_output/BrutusLogOn.h>
#include <idl_output/IMAPISession.h>
#include <session/brutus-proxy.h>
#include <session/brutusd-util.h>
#include "brutus.h"

G_BEGIN_DECLS

#define BRUTUS_SERVER_REQ_VERSION_STRING "0.9.35"

enum E_SOURCE_BRUTUS_TYPE {
	E_SOURCE_BRUTUS_CALENDAR,
	E_SOURCE_BRUTUS_TASKS,
	E_SOURCE_BRUTUS_JOURNAL,
	E_SOURCE_BRUTUS_ADDRESSBOOK
};

/*
 * Returns TRUE if the version of the remote Brutus Server is 
 * supported.
 */
extern gboolean brutus_server_version_OK(int major,
					 int minor,
					 int micro,
					 int release_tag);

/*
 * Both of these are for use in g_list_foreach() and g_slist_foreach()
 */
extern void brutus_for_each_free(gpointer data,
				 gpointer user_data);

extern void brutus_for_each_g_free(gpointer data,
				   gpointer user_data);

/*
 * time_zone_offset: offset from GMT in minutes - east is negative, west
 * is positive
 *
 * Will return 100 if time_zone_offset is -60.
 * Will return 130 if time_zone_offset is -90.
 */
extern int brutus_timezone_to_gmt_offset(long time_zone_offset);

/*
 * This will add a Brutus ECal source to gconf
 */
extern gboolean brutus_add_account(const enum E_SOURCE_BRUTUS_TYPE e_type,
				   const char *account_name,
				   const char *mapi_profile,
				   const char *exchange_server,
				   const char *windows_user,
				   const char *exchange_mailbox,
				   const char *exchange_mailbox_dn,
				   const char *exchange_mailbox_email,
				   const char *windows_domain,
				   const char *brutus_server,
				   const char *brutus_port,
				   const gboolean use_ssl,
				   int auto_check_timeout); // in minutes

extern gboolean brutus_logon_loop(BRUTUS_BrutusLogOn brutus_logon,
				  BRUTUS_BrutusCheck lifeline,
				  BRUTUS_IMAPISession *mapi_session,
				  CORBA_unsigned_long *instance_id,
				  char **mapi_profile,
				  const char *prompt,
				  const char *err_prompt,
				  const char *windows_user,
				  const char *windows_domain,
				  const char *exchange_mailbox,
				  const char *exchange_mailbox_dn,
				  const char *exchange_mailbox_email,
				  const char *exchange_server);

/*
 * Will get the stringified MD5 digest of 'str'
 */
extern void brutus_get_digest_str(const char *str,
				  digest_str_t digest_str);

/*
 * Caller must g_free() the return value
 */
extern gchar *brutus_strip_trailing_and_leading_whitespace(const char *str);

/*
 * Will generate a UUID string
 */
extern void get_random_uuid(uuid_str_t uuid_str);


G_END_DECLS

#endif /* _BRUTUS_UTIL_H_ */
